==> haskell-http-date-0.0.8-70-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-date.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-date
version:              0.0.8
visibility:           public
id:                   http-date-0.0.8-35bqYznvuPdIz8fKssMeTX
key:                  http-date-0.0.8-35bqYznvuPdIz8fKssMeTX
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             HTTP Date parser/formatter
description:          Fast parser and formatter for HTTP Date
category:             Network, Web
abi:                  043e9df3c03212b1a4fe7c911ec226ea
exposed:              True
exposed-modules:      Network.HTTP.Date
hidden-modules:
    Network.HTTP.Date.Converter Network.HTTP.Date.Formatter
    Network.HTTP.Date.Types Network.HTTP.Date.Parser

import-dirs:          /usr/lib/ghc-8.10.2/site-local/http-date-0.0.8
library-dirs:         /usr/lib/ghc-8.10.2/site-local/http-date-0.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/http-date-0.0.8
hs-libraries:         HShttp-date-0.0.8-35bqYznvuPdIz8fKssMeTX
depends:
    array-0.5.4.0 attoparsec-0.13.2.4-8ozNPIXXMcDHzUghDR61gU
    base-4.14.1.0 bytestring-0.10.10.0 time-1.9.3

haddock-interfaces:   /usr/share/doc/haskell-http-date/html/http-date.haddock
haddock-html:         /usr/share/doc/haskell-http-date/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-date-0.0.8-73-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-date.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-date
version:              0.0.8
visibility:           public
id:                   http-date-0.0.8-4rcFZu7EOVqHAmnOsAakqo
key:                  http-date-0.0.8-4rcFZu7EOVqHAmnOsAakqo
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             HTTP Date parser/formatter
description:          Fast parser and formatter for HTTP Date
category:             Network, Web
abi:                  fa4e515a88ac091732b69fd64783412d
exposed:              True
exposed-modules:      Network.HTTP.Date
hidden-modules:
    Network.HTTP.Date.Converter Network.HTTP.Date.Formatter
    Network.HTTP.Date.Types Network.HTTP.Date.Parser

import-dirs:          /usr/lib/ghc-8.10.2/site-local/http-date-0.0.8
library-dirs:         /usr/lib/ghc-8.10.2/site-local/http-date-0.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/http-date-0.0.8
hs-libraries:         HShttp-date-0.0.8-4rcFZu7EOVqHAmnOsAakqo
depends:
    array-0.5.4.0 attoparsec-0.13.2.4-4EqQxnqmXuA5lAbmzZWVma
    base-4.14.1.0 bytestring-0.10.10.0 time-1.9.3

haddock-interfaces:   /usr/share/doc/haskell-http-date/html/http-date.haddock
haddock-html:         /usr/share/doc/haskell-http-date/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
